"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.query_api import QueryApi  # noqa: E501


class TestQueryApi(unittest.TestCase):
    """QueryApi unit test stubs"""

    def setUp(self):
        self.api = QueryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_lucene_query(self):
        """Test case for post_lucene_query

        Query a dataset using the lucene query syntax  # noqa: E501
        """
        pass

    def test_post_lucene_query_document(self):
        """Test case for post_lucene_query_document

        Query document for a dataset using the lucene query syntax  # noqa: E501
        """
        pass

    def test_post_query(self):
        """Test case for post_query

        Query a dataset  # noqa: E501
        """
        pass

    def test_post_query_summary(self):
        """Test case for post_query_summary

        Query all datasets  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_groups_id(self):
        """Test case for delete_groups_id

        Removes the group with the given id  # noqa: E501
        """
        pass

    def test_get_groups(self):
        """Test case for get_groups

        Retrieves a list of groups from the groups service  # noqa: E501
        """
        pass

    def test_get_groups_id(self):
        """Test case for get_groups_id

        Retrieves a group with the given id from the service  # noqa: E501
        """
        pass

    def test_patch_groups_id(self):
        """Test case for patch_groups_id

        Updates the resource with the given id  # noqa: E501
        """
        pass

    def test_post_groups(self):
        """Test case for post_groups

        Create a new group  # noqa: E501
        """
        pass

    def test_put_groups_id(self):
        """Test case for put_groups_id

        Updates the group with given id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from kdp_api.api_client import ApiClient, Endpoint as _Endpoint
from kdp_api.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from kdp_api.model.api_error import ApiError
from kdp_api.model.audit_log_configuration import AuditLogConfiguration
from kdp_api.model.audit_log_configuration_paginator import AuditLogConfigurationPaginator
 


class AuditLogConfigsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_all_auditlog_configurations_endpoint = _Endpoint(
            settings={
                'response_type': (AuditLogConfigurationPaginator,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/audit-log-configs/',
                'operation_id': 'get_all_auditlog_configurations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'workspace_id',
                    'keep_forever',
                    'limit',
                    'skip',
                    'sort',
                    'filter',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'workspace_id':
                        (str,),
                    'keep_forever':
                        (bool,),
                    'limit':
                        (int,),
                    'skip':
                        (int,),
                    'sort':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                    'filter':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'workspace_id': 'workspaceId',
                    'keep_forever': 'keepForever',
                    'limit': '$limit',
                    'skip': '$skip',
                    'sort': '$sort',
                    'filter': 'filter',
                },
                'location_map': {
                    'workspace_id': 'query',
                    'keep_forever': 'query',
                    'limit': 'query',
                    'skip': 'query',
                    'sort': 'query',
                    'filter': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_auditlog_configuration_endpoint = _Endpoint(
            settings={
                'response_type': (AuditLogConfiguration,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/audit-log-configs/{logConfigurationId}',
                'operation_id': 'get_auditlog_configuration',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'log_configuration_id',
                ],
                'required': [
                    'log_configuration_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'log_configuration_id':
                        (str,),
                },
                'attribute_map': {
                    'log_configuration_id': 'logConfigurationId',
                },
                'location_map': {
                    'log_configuration_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_auditlog_configuration_endpoint = _Endpoint(
            settings={
                'response_type': (AuditLogConfiguration,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/audit-log-configs/{auditLogConfigsId}',
                'operation_id': 'patch_auditlog_configuration',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'audit_log_configs_id',
                    'audit_log_configuration',
                ],
                'required': [
                    'audit_log_configs_id',
                    'audit_log_configuration',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'audit_log_configs_id':
                        (str,),
                    'audit_log_configuration':
                        (AuditLogConfiguration,),
                },
                'attribute_map': {
                    'audit_log_configs_id': 'auditLogConfigsId',
                },
                'location_map': {
                    'audit_log_configs_id': 'path',
                    'audit_log_configuration': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.put_auditlog_configuration_endpoint = _Endpoint(
            settings={
                'response_type': (AuditLogConfiguration,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/audit-log-configs/{auditLogConfigsId}',
                'operation_id': 'put_auditlog_configuration',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'audit_log_configs_id',
                    'audit_log_configuration',
                ],
                'required': [
                    'audit_log_configs_id',
                    'audit_log_configuration',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'audit_log_configs_id':
                        (str,),
                    'audit_log_configuration':
                        (AuditLogConfiguration,),
                },
                'attribute_map': {
                    'audit_log_configs_id': 'auditLogConfigsId',
                },
                'location_map': {
                    'audit_log_configs_id': 'path',
                    'audit_log_configuration': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_all_auditlog_configurations(
        self,
        **kwargs
    ):
        """Get audit log configuration  # noqa: E501

        Get all audit log configuration of all workspaces  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_auditlog_configurations(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            workspace_id (str): Return the audit log configurations. [optional]
            keep_forever (bool): Return the audit log configurations. [optional]
            limit (int): Number of results to return. [optional]
            skip (int): Number of results to skip. [optional]
            sort ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Property to sort results. [optional]
            filter ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Query parameters to filter. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AuditLogConfigurationPaginator
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_all_auditlog_configurations_endpoint.call_with_http_info(**kwargs)

    def get_auditlog_configuration(
        self,
        log_configuration_id,
        **kwargs
    ):
        """Get audit log configuration of a workspace by configuration Id  # noqa: E501

        Get audit log configuration of a workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auditlog_configuration(log_configuration_id, async_req=True)
        >>> result = thread.get()

        Args:
            log_configuration_id (str): The id of the audit log configuration

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AuditLogConfiguration
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['log_configuration_id'] = \
            log_configuration_id
        return self.get_auditlog_configuration_endpoint.call_with_http_info(**kwargs)

    def patch_auditlog_configuration(
        self,
        audit_log_configs_id,
        audit_log_configuration,
        **kwargs
    ):
        """Patch audit log configuration of a workspace  # noqa: E501

        Patch audit log configuration of a workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_auditlog_configuration(audit_log_configs_id, audit_log_configuration, async_req=True)
        >>> result = thread.get()

        Args:
            audit_log_configs_id (str): ID of the audit log configuration
            audit_log_configuration (AuditLogConfiguration):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AuditLogConfiguration
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['audit_log_configs_id'] = \
            audit_log_configs_id
        kwargs['audit_log_configuration'] = \
            audit_log_configuration
        return self.patch_auditlog_configuration_endpoint.call_with_http_info(**kwargs)

    def put_auditlog_configuration(
        self,
        audit_log_configs_id,
        audit_log_configuration,
        **kwargs
    ):
        """Modify audit log configuration of a workspace  # noqa: E501

        Modify audit log configuration of a workspace  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.put_auditlog_configuration(audit_log_configs_id, audit_log_configuration, async_req=True)
        >>> result = thread.get()

        Args:
            audit_log_configs_id (str): ID of the audit log configuration
            audit_log_configuration (AuditLogConfiguration):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AuditLogConfiguration
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['audit_log_configs_id'] = \
            audit_log_configs_id
        kwargs['audit_log_configuration'] = \
            audit_log_configuration
        return self.put_auditlog_configuration_endpoint.call_with_http_info(**kwargs)




"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import kdp_api
from kdp_api.model.segment import Segment


class TestSegment(unittest.TestCase):
    """Segment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSegment(self):
        """Test Segment"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Segment()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.attributes_api import AttributesApi  # noqa: E501


class TestAttributesApi(unittest.TestCase):
    """AttributesApi unit test stubs"""

    def setUp(self):
        self.api = AttributesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attributes_id(self):
        """Test case for delete_attributes_id

        Remove Attribute with the given ID  # noqa: E501
        """
        pass

    def test_get_attributes(self):
        """Test case for get_attributes

        Retrieves a list of Attributes  # noqa: E501
        """
        pass

    def test_get_attributes_id(self):
        """Test case for get_attributes_id

        Retrieve Attribute with the given ID  # noqa: E501
        """
        pass

    def test_patch_attributes_id(self):
        """Test case for patch_attributes_id

        Update provided fields of Attribute with the given ID  # noqa: E501
        """
        pass

    def test_post_attributes(self):
        """Test case for post_attributes

        Creates a new Attribute  # noqa: E501
        """
        pass

    def test_put_attributes_id(self):
        """Test case for put_attributes_id

        Update Attribute with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.audit_log_configs_api import AuditLogConfigsApi  # noqa: E501


class TestAuditLogConfigsApi(unittest.TestCase):
    """AuditLogConfigsApi unit test stubs"""

    def setUp(self):
        self.api = AuditLogConfigsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_all_auditlog_configurations(self):
        """Test case for get_all_auditlog_configurations

        Get audit log configuration  # noqa: E501
        """
        pass

    def test_get_auditlog_configuration(self):
        """Test case for get_auditlog_configuration

        Get audit log configuration of a workspace by configuration Id  # noqa: E501
        """
        pass

    def test_patch_auditlog_configuration(self):
        """Test case for patch_auditlog_configuration

        Patch audit log configuration of a workspace  # noqa: E501
        """
        pass

    def test_put_auditlog_configuration(self):
        """Test case for put_auditlog_configuration

        Modify audit log configuration of a workspace  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.ingest_api import IngestApi  # noqa: E501


class TestIngestApi(unittest.TestCase):
    """IngestApi unit test stubs"""

    def setUp(self):
        self.api = IngestApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_ingest(self):
        """Test case for post_ingest

        Create an Ingest Job  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from kdp_api.api_client import ApiClient, Endpoint as _Endpoint
from kdp_api.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from kdp_api.model.api_error import ApiError
from kdp_api.model.create_a_transfer_resource_request import CreateATransferResourceRequest
from kdp_api.model.inline_object import InlineObject
from kdp_api.model.transfer_resource_request import TransferResourceRequest
from kdp_api.model.transfer_resource_request_paginator import TransferResourceRequestPaginator
 


class TransferResourceRequestsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_transfer_resource_requests_endpoint = _Endpoint(
            settings={
                'response_type': (TransferResourceRequestPaginator,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/transfer-resource-requests',
                'operation_id': 'get_transfer_resource_requests',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'skip',
                    'sort',
                    'recipient',
                    'status',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'status',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('status',): {

                        "ACCEPTED": "accepted",
                        "DECLINED": "declined",
                        "PENDING": "pending",
                        "REVOKED": "revoked"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'skip':
                        (int,),
                    'sort':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                    'recipient':
                        (bool,),
                    'status':
                        (str,),
                },
                'attribute_map': {
                    'limit': '$limit',
                    'skip': '$skip',
                    'sort': '$sort',
                    'recipient': 'recipient',
                    'status': 'status',
                },
                'location_map': {
                    'limit': 'query',
                    'skip': 'query',
                    'sort': 'query',
                    'recipient': 'query',
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_transfer_resource_requests_id_endpoint = _Endpoint(
            settings={
                'response_type': (TransferResourceRequest,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/transfer-resource-requests/{id}',
                'operation_id': 'get_transfer_resource_requests_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.patch_transfer_resource_requests_id_endpoint = _Endpoint(
            settings={
                'response_type': (TransferResourceRequest,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/transfer-resource-requests/{id}',
                'operation_id': 'patch_transfer_resource_requests_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'inline_object',
                ],
                'required': [
                    'id',
                    'inline_object',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'inline_object':
                        (InlineObject,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                    'inline_object': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.post_transfer_resource_requests_endpoint = _Endpoint(
            settings={
                'response_type': (TransferResourceRequest,),
                'auth': [
                    'Bearer'
                ],
                'endpoint_path': '/transfer-resource-requests',
                'operation_id': 'post_transfer_resource_requests',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_a_transfer_resource_request',
                ],
                'required': [
                    'create_a_transfer_resource_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_a_transfer_resource_request':
                        (CreateATransferResourceRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_a_transfer_resource_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_transfer_resource_requests(
        self,
        **kwargs
    ):
        """Retrieves a list of transfer resource requests  # noqa: E501

        By default, this endpoint responds with the transfer-requests that were initiated by the current user. \\ If the userId or recipientUserId query params contain a value that does not match the current user's ID, the endpoint will throw a Bad Request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transfer_resource_requests(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            limit (int): Number of results to return. [optional]
            skip (int): Number of results to skip. [optional]
            sort ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): Property to sort results. [optional]
            recipient (bool): If `recipient` is present in the request, the endpoint will respond with transfer requests <b>intended</b> for the current user \\ Otherwise, the response will include transfer requests <b>initiated</b> by the current user . [optional]
            status (str): Filters the transfer resource requests by status. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TransferResourceRequestPaginator
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_transfer_resource_requests_endpoint.call_with_http_info(**kwargs)

    def get_transfer_resource_requests_id(
        self,
        id,
        **kwargs
    ):
        """Retrieves a transfer resource request with the given ID  # noqa: E501

        If the userId or recipientUserId does not match the current user's ID, the endpoint will throw a Bad Request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_transfer_resource_requests_id(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of transfer resource request to return

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TransferResourceRequest
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.get_transfer_resource_requests_id_endpoint.call_with_http_info(**kwargs)

    def patch_transfer_resource_requests_id(
        self,
        id,
        inline_object,
        **kwargs
    ):
        """Patches the transfer resource request status by id  # noqa: E501

        Transfer resource request status can only be updated if the current status is equal to `pending`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_transfer_resource_requests_id(id, inline_object, async_req=True)
        >>> result = thread.get()

        Args:
            id (str): ID of transfer request to patch
            inline_object (InlineObject):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TransferResourceRequest
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        kwargs['inline_object'] = \
            inline_object
        return self.patch_transfer_resource_requests_id_endpoint.call_with_http_info(**kwargs)

    def post_transfer_resource_requests(
        self,
        create_a_transfer_resource_request,
        **kwargs
    ):
        """Create a transfer resource request  # noqa: E501

        Transfer resource requests are limited to resource owners.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.post_transfer_resource_requests(create_a_transfer_resource_request, async_req=True)
        >>> result = thread.get()

        Args:
            create_a_transfer_resource_request (CreateATransferResourceRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            TransferResourceRequest
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['create_a_transfer_resource_request'] = \
            create_a_transfer_resource_request
        return self.post_transfer_resource_requests_endpoint.call_with_http_info(**kwargs)




"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.dataset_permissions_api import DatasetPermissionsApi  # noqa: E501


class TestDatasetPermissionsApi(unittest.TestCase):
    """DatasetPermissionsApi unit test stubs"""

    def setUp(self):
        self.api = DatasetPermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_dataset_permissions_id(self):
        """Test case for delete_dataset_permissions_id

        Remove Dataset Permission with given ID  # noqa: E501
        """
        pass

    def test_get_dataset_permissions(self):
        """Test case for get_dataset_permissions

        Retrieve list of dataset permissions  # noqa: E501
        """
        pass

    def test_get_dataset_permissions_id(self):
        """Test case for get_dataset_permissions_id

        Retrieve a Dataset Permission with the given ID  # noqa: E501
        """
        pass

    def test_patch_dataset_permissions_id(self):
        """Test case for patch_dataset_permissions_id

        Update provided fields of Dataset Permission with given ID  # noqa: E501
        """
        pass

    def test_post_dataset_permissions(self):
        """Test case for post_dataset_permissions

        Create a new Dataset Permission  # noqa: E501
        """
        pass

    def test_put_dataset_permissions_id(self):
        """Test case for put_dataset_permissions_id

        Update Dataset Permission with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.users_api import UsersApi  # noqa: E501


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_users_id(self):
        """Test case for delete_users_id

        Removes the user by given id  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Retrieves a list of users  # noqa: E501
        """
        pass

    def test_get_users_id(self):
        """Test case for get_users_id

        Retrieves a user with the given id from the users service.  # noqa: E501
        """
        pass

    def test_patch_users_id(self):
        """Test case for patch_users_id

        Updates the resource by id for the fields provided  # noqa: E501
        """
        pass

    def test_post_user(self):
        """Test case for post_user

        Create a user  # noqa: E501
        """
        pass

    def test_put_users_id(self):
        """Test case for put_users_id

        Updates a user with given id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 4.53.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.transfer_resource_requests_api import TransferResourceRequestsApi  # noqa: E501


class TestTransferResourceRequestsApi(unittest.TestCase):
    """TransferResourceRequestsApi unit test stubs"""

    def setUp(self):
        self.api = TransferResourceRequestsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transfer_resource_requests(self):
        """Test case for get_transfer_resource_requests

        Retrieves a list of transfer resource requests  # noqa: E501
        """
        pass

    def test_get_transfer_resource_requests_id(self):
        """Test case for get_transfer_resource_requests_id

        Retrieves a transfer resource request with the given ID  # noqa: E501
        """
        pass

    def test_patch_transfer_resource_requests_id(self):
        """Test case for patch_transfer_resource_requests_id

        Patches the transfer resource request status by id  # noqa: E501
        """
        pass

    def test_post_transfer_resource_requests(self):
        """Test case for post_transfer_resource_requests

        Create a transfer resource request  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
